pub enum When {
    Polling,
    SendingMessage(Option<SocketAddr>, IdToken),
    None,
}
The context that an error occurred in

Variants

Polling

We were polling for a message when the error occurred

SendingMessage(Option<SocketAddr>, IdToken)

We were sending a message

None

Not sure that When is valuable anymore

Implementations

Construct a specific error from the context the error occurred in