Configures toad to use Vec for collections,
UdpSocket for networking,
and crate::std::Clock for timing
use toad::platform::Std;
use toad::req::Req;
Req::<Std>::get("192.168.0.1:5683".parse().unwrap(), "/hello");Trait Implementations
sourceimpl<Clk: Clock<T = u64> + Debug + 'static, Sock: Socket + 'static> Platform for Alloc<Clk, Sock>
impl<Clk: Clock<T = u64> + Debug + 'static, Sock: Socket + 'static> Platform for Alloc<Clk, Sock>
type MessagePayload = Vec<u8, Global>
type MessagePayload = Vec<u8, Global>
What type should we use to store the message payloads?
type MessageOptionBytes = Vec<u8, Global>
type MessageOptionBytes = Vec<u8, Global>
What type should we use to store the option values?
type MessageOptions = Vec<Opt<Vec<u8, Global>>, Global>
type MessageOptions = Vec<Opt<Vec<u8, Global>>, Global>
What type should we use to store the options?
type MessageIdHistory = Vec<Stamped<<Alloc<Clk, Sock> as Platform>::Clock, Id>, Global>
type MessageIdHistory = Vec<Stamped<<Alloc<Clk, Sock> as Platform>::Clock, Id>, Global>
What type should we use to keep track of message IDs we’ve seen with a remote socket?
type MessageTokenHistory = Vec<Stamped<<Alloc<Clk, Sock> as Platform>::Clock, Token>, Global>
type MessageTokenHistory = Vec<Stamped<<Alloc<Clk, Sock> as Platform>::Clock, Token>, Global>
What type should we use to keep track of message Tokens we’ve seen with a remote socket?
type MessageIdHistoryBySocket = BTreeMap<SocketAddr, <Alloc<Clk, Sock> as Platform>::MessageIdHistory, Global>
type MessageIdHistoryBySocket = BTreeMap<SocketAddr, <Alloc<Clk, Sock> as Platform>::MessageIdHistory, Global>
How do we track socket <> id histories?
type MessageTokenHistoryBySocket = BTreeMap<SocketAddr, <Alloc<Clk, Sock> as Platform>::MessageTokenHistory, Global>
type MessageTokenHistoryBySocket = BTreeMap<SocketAddr, <Alloc<Clk, Sock> as Platform>::MessageTokenHistory, Global>
How do we track socket <> token histories?
type NumberedOptions = Vec<(OptNumber, Opt<Vec<u8, Global>>), Global>
type NumberedOptions = Vec<(OptNumber, Opt<Vec<u8, Global>>), Global>
What type should we use to keep track of options before serializing?
type Clock = Clk
type Clock = Clk
What should we use to keep track of time?
type Socket = Sock
type Socket = Sock
What should we use for networking?
impl<Clk: Copy, Sock: Copy> Copy for Alloc<Clk, Sock>where
Clk: Clock<T = u64> + 'static,
Sock: Socket + 'static,