toad configuration trait

Required Associated Types

What type should we use to store the message payloads?

What type should we use to store the option values?

What type should we use to store the options?

What type should we use to keep track of message IDs we’ve seen with a remote socket?

How do we track socket <> id histories?

What type should we use to keep track of message Tokens we’ve seen with a remote socket?

How do we track socket <> token histories?

What type should we use to keep track of options before serializing?

What should we use to keep track of time?

What should we use for networking?

Implementors